import{d as u,ez as b,G as m,a as f,b as g,c as v,w as i,f as s}from"./outputWidgets.0fb707c7.js";import{B as _}from"./BaseLayout.4284e9c0.js";import{a as h}from"./asyncComputed.a0ca296c.js";import{P as y}from"./project.f9503600.js";import"./router.81de177d.js";import{O as z}from"./organization.510c9436.js";import"./columns.37a1e6f7.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.78422c92.js";import{S as I}from"./Sidebar.912353ba.js";import{n as w,J as k,K as B,L as P,M as $,N as C,O as M,G as x,H as D,I as L}from"./icons.24a85994.js";import"./gateway.7ee47e62.js";import"./activeRecord.204186f3.js";import"./pubsub.7d8bce56.js";import"./Form.0dcb97c0.js";import"./Title.f00a58f9.js";import"./transButton.220177fb.js";import"./Text.3ec0a64d.js";import"./index.140c5bc8.js";import"./index.cf4c23b9.js";import"./logo.084e5d7c.js";import"./index.a2e845fd.js";import"./index.ebe62e37.js";import"./Tooltip.dde008dc.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="0df4160f-02ef-4f6a-8e8d-1d59abbd52ff",o._sentryDebugIdIdentifier="sentry-dbid-0df4160f-02ef-4f6a-8e8d-1d59abbd52ff")}catch{}})();const ta=u({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=f("router-view");return g(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{ta as default};
//# sourceMappingURL=Project.561a205e.js.map
