import{d as y,ey as g,ez as v,r as _,b as r,c as a,w as s,u as t,f as n,ev as m}from"./outputWidgets.0fb707c7.js";import{S as h,L as w}from"./SmartConsole.cb276e5d.js";import{a as x}from"./asyncComputed.a0ca296c.js";import{H as B}from"./hooks.050c60fa.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.cb07d15b.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.6262c519.js";import{B as I}from"./BaseLayout.4284e9c0.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.0c43be08.js";import{_ as $}from"./Debugger.vue_vue_type_script_setup_true_lang.0be10547.js";import{c as D}from"./index.ebe62e37.js";import{A as k,T as R}from"./TabPane.52e10a91.js";import"./forms.d1706940.js";import"./activeRecord.204186f3.js";import"./pubsub.7d8bce56.js";import"./dashes.732fbcbe.js";import"./runnerData.123d166f.js";import"./jobs.a07f20aa.js";import"./workspaces.3d9f34c7.js";import"./url.d43b75f5.js";import"./icons.24a85994.js";import"./Title.f00a58f9.js";import"./transButton.220177fb.js";import"./index.8dbf2994.js";import"./uuid.4028e63a.js";import"./ant-design.c18e1d39.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.4cc3706c.js";import"./RunButton.vue_vue_type_script_setup_true_lang.05efc5c6.js";import"./index.088bfcfb.js";import"./index.0d3d2205.js";import"./CollapsePanel.d73eca3e.js";import"./index.a2e845fd.js";import"./index.e8ef1073.js";import"./index.85d2f01b.js";import"./Form.0dcb97c0.js";import"./Text.3ec0a64d.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},p=new Error().stack;p&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[p]="ba040dc6-b82a-4404-ab3d-a82bc723f5b3",i._sentryDebugIdIdentifier="sentry-dbid-ba040dc6-b82a-4404-ab3d-a82bc723f5b3")}catch{}})();const _t=y({__name:"HookEditor",setup(i){const p=g(),l=v(),c=_(null),o=_("test");function b(){p.push({name:"hooks"})}const{result:e}=x(()=>B.get(l.params.hookPath)),f=w.create();return(A,d)=>(r(),a(I,null,{navbar:s(()=>[t(e)?(r(),a(t(D),{key:0,title:t(e).title,style:{padding:"5px 10px"},onBack:b},{footer:s(()=>[n(t(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:s(()=>[n(t(k),{key:"test",tab:"Test"}),n(t(k),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:s(()=>[n($),n(H,{path:"hooks"}),o.value==="settings"?(r(),a(C,{key:0,model:t(e)},null,8,["model"])):m("",!0)]),_:1},8,["title"])):m("",!0)]),content:s(()=>[t(e)&&o.value==="test"?(r(),a(S,{key:0,ref_key:"tester",ref:c,hook:t(e),"log-service":t(f)},null,8,["hook","log-service"])):m("",!0),t(e)&&o.value==="settings"?(r(),a(T,{key:1,hook:t(e)},null,8,["hook"])):m("",!0)]),footer:s(()=>{var u;return[t(e)&&o.value==="test"?(r(),a(h,{key:0,runtime:"forms","log-service":t(f),onRestart:(u=c.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):m("",!0)]}),_:1}))}});export{_t as default};
//# sourceMappingURL=HookEditor.4b1532fa.js.map
