import{t as o,a as i,b as a,c,i as d,T as p,j as f,P as u,C as _,M as l,s as g,k as s,l as m,m as y,n as b,p as v}from"./outputWidgets.0fb707c7.js";import{u as w,s as h,a as r}from"./index.4da42521.js";import"./pubsub.7d8bce56.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6f41f31b-e569-4f72-a61c-5dfc62203ede",e._sentryDebugIdIdentifier="sentry-dbid-6f41f31b-e569-4f72-a61c-5dfc62203ede")}catch{}})();const I={};function k(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=d({render:()=>m(x)});p.init(),f(e,r),P.init(),e.use(r),e.use(u),e.mount("#app"),e.component("VSelect",_),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.82a8da23.js.map
