import{U as t,f as i,O as d,ab as y}from"./outputWidgets.0fb707c7.js";import{B as c,c as l}from"./Title.f00a58f9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="110ed645-bd10-494c-a38d-df5debec861f",e._sentryDebugIdIdentifier="sentry-dbid-110ed645-bd10-494c-a38d-df5debec861f")}catch{}})();const b=()=>d(l(),["component"]),r=(e,s)=>{let{slots:o,attrs:p}=s;const a=t(t(t({},e),{component:"div"}),p);return i(c,a,o)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=b();const m=r,g=()=>t(t({},d(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),n=(e,s)=>{let{slots:o,attrs:p}=s;const{ellipsis:a}=e;y();const f=t(t(t({},e),{ellipsis:a&&typeof a=="object"?d(a,["expandable","rows"]):a,component:"span"}),p);return i(c,f,o)};n.displayName="ATypographyText";n.inheritAttrs=!1;n.props=g();const x=n;export{m as A,x as a};
//# sourceMappingURL=Text.3ec0a64d.js.map
