import"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="0d9645ab-25c9-4ece-9923-39dd1d945b08",e._sentryDebugIdIdentifier="sentry-dbid-0d9645ab-25c9-4ece-9923-39dd1d945b08")}catch{}})();function r(e,d){const i=document,n=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),s=d.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);n?i.title=n.meta.title:s&&(i.title=s.meta.title)}export{r as u};
//# sourceMappingURL=index.140c5bc8.js.map
