import"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6bc5588f-528e-4245-81ec-3ef277454b51",e._sentryDebugIdIdentifier="sentry-dbid-6bc5588f-528e-4245-81ec-3ef277454b51")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.d43b75f5.js.map
