[data-v-7b8037ee]:root{--main-font-family: DM Sans, sans-serif}[data-v-7b8037ee]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-7b8037ee]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-7b8037ee]{background-color:#fff;padding:10px}.login-block[data-v-7b8037ee]{display:flex;align-items:center;gap:5px}.login-block .button[data-v-7b8037ee]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026;font-size:12px}.login-block .button[data-v-7b8037ee]:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.login-block .button[data-v-7b8037ee]:active,.login-block .button active[data-v-7b8037ee]{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}
