import{x as s}from"./icons.24a85994.js";import{d as c,a as r,b as i,et as d,f as _,u as l,aA as u,t as f}from"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3917f4b4-a11d-45ea-8c16-c98c2e7b5425",e._sentryDebugIdIdentifier="sentry-dbid-3917f4b4-a11d-45ea-8c16-c98c2e7b5425")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.0c9cf904.js.map
