import{d as r,r as u,o as c,eS as f,b as y,c as p,w as d,f as b,aA as g,eB as m,eO as w,u as i,bZ as k,eW as _}from"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c8a343f8-ea6d-4864-9094-8db337d90259",e._sentryDebugIdIdentifier="sentry-dbid-c8a343f8-ea6d-4864-9094-8db337d90259")}catch{}})();const B=r({__name:"ActionButton",props:{action:{},displayName:{},loading:{type:Boolean}},emits:["click"],setup(e,{emit:n}){const a=e,o=u(null);return c(()=>{o.value&&a.action.setElement(o.value),f.addAction(a.action)}),(s,t)=>(y(),p(i(_),null,{default:d(()=>[b(i(k),{ref_key:"element",ref:o,class:"next-button",loading:s.loading,onClick:t[0]||(t[0]=l=>n("click")),onKeydown:t[1]||(t[1]=w(l=>n("click"),["enter"]))},{default:d(()=>[g(m(s.displayName),1)]),_:1},8,["loading"])]),_:1}))}});export{B as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.c56900fa.js.map
