import{d as u,ez as b,G as f,b as y,c as g,u as _}from"./outputWidgets.0fb707c7.js";import{a as w}from"./asyncComputed.a0ca296c.js";import"./router.81de177d.js";import{M as m}from"./member.661fed75.js";import"./columns.37a1e6f7.js";import{C as I}from"./CrudView.e365e55f.js";import"./Form.0dcb97c0.js";import"./Title.f00a58f9.js";import"./transButton.220177fb.js";import"./Text.3ec0a64d.js";import"./index.140c5bc8.js";import"./gateway.7ee47e62.js";import"./activeRecord.204186f3.js";import"./pubsub.7d8bce56.js";import"./index.cf4c23b9.js";import"./icons.24a85994.js";import"./url.d43b75f5.js";import"./index.85d2f01b.js";import"./index.8dbf2994.js";import"./index.0d3d2205.js";import"./index.e8ef1073.js";import"./index.a2e845fd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dd2d73c5-f5ee-42b4-9681-06eb23b66daa",e._sentryDebugIdIdentifier="sentry-dbid-dd2d73c5-f5ee-42b4-9681-06eb23b66daa")}catch{}})();const K=u({__name:"Members",setup(e){const r=b().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),p()},{loading:d,result:l,refetch:p}=w(()=>m.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=l.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Members.a0f0ae55.js.map
