import{t as n,b as s,et as o}from"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="12d82f89-94f9-42dc-8663-674c3f178297",e._sentryDebugIdIdentifier="sentry-dbid-12d82f89-94f9-42dc-8663-674c3f178297")}catch{}})();const r={},d={class:"organization-settings"};function i(e,t){return s(),o("div",d,"Organization settings")}const a=n(r,[["render",i]]);export{a as default};
//# sourceMappingURL=OrganizationSettings.d0da18bf.js.map
