import{cz as r}from"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="2ebe30bb-d924-4b70-9a5c-262d8d4c6a64",e._sentryDebugIdIdentifier="sentry-dbid-2ebe30bb-d924-4b70-9a5c-262d8d4c6a64")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.c01c5f2c.js.map
