import{U as s}from"./outputWidgets.0fb707c7.js";import{c as i,d}from"./index.215cc261.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="063d9379-623b-4e58-809c-2a8fbc1ab314",e._sentryDebugIdIdentifier="sentry-dbid-063d9379-623b-4e58-809c-2a8fbc1ab314")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:a}=i(d),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.c5abb343.js.map
