import{R as n}from"./Title.f00a58f9.js";import{D as a}from"./outputWidgets.0fb707c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fb09c710-b342-466e-a9a1-079aca0b0457",e._sentryDebugIdIdentifier="sentry-dbid-fb09c710-b342-466e-a9a1-079aca0b0457")}catch{}})();const d=a(n);export{d as A};
//# sourceMappingURL=index.8dbf2994.js.map
