import{S as p}from"./Sidebar.912353ba.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.78422c92.js";import{G as l,H as u,I as d}from"./icons.24a85994.js";import{d as b,ez as f,G as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.0fb707c7.js";import{a as w}from"./asyncComputed.a0ca296c.js";import"./router.81de177d.js";import{O as z}from"./organization.510c9436.js";import"./columns.37a1e6f7.js";import{B as h}from"./BaseLayout.4284e9c0.js";import"./Tooltip.dde008dc.js";import"./logo.084e5d7c.js";import"./Text.3ec0a64d.js";import"./Title.f00a58f9.js";import"./transButton.220177fb.js";import"./index.a2e845fd.js";import"./index.ebe62e37.js";import"./Form.0dcb97c0.js";import"./index.140c5bc8.js";import"./gateway.7ee47e62.js";import"./activeRecord.204186f3.js";import"./pubsub.7d8bce56.js";import"./index.cf4c23b9.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="b981c242-9c8e-42e4-9af1-81802f46b871",o._sentryDebugIdIdentifier="sentry-dbid-b981c242-9c8e-42e4-9af1-81802f46b871")}catch{}})();const Q=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:d,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{Q as default};
//# sourceMappingURL=Organization.76dec97a.js.map
